@@ -600,25 +600,6 @@ int grib_compare_accessors(grib_accessor* a1, grib_accessor* a2, int compare_fla
     return ret;
 }
 
-const char* grib_get_type_name(int type)
-{
-    switch (type) {
-        case GRIB_TYPE_LONG:
-            return "long";
-        case GRIB_TYPE_STRING:
-            return "string";
-        case GRIB_TYPE_BYTES:
-            return "bytes";
-        case GRIB_TYPE_DOUBLE:
-            return "double";
-        case GRIB_TYPE_LABEL:
-            return "label";
-        case GRIB_TYPE_SECTION:
-            return "section";
-    }
-    return "unknown";
-}
-
 /*
 int grib_accessor_clear_attributes(grib_accessor* a)
 {
@@ -789,7 +770,7 @@ grib_accessors_list* grib_accessors_list_last(grib_accessors_list* al)
     return al->last;
 }
 
-grib_accessors_list* grib_accessors_list_find(grib_accessors_list* al, grib_accessor* a)
+grib_accessors_list* grib_accessors_list_find(grib_accessors_list* al, const grib_accessor* a)
 {
     grib_accessors_list* last = al;
     grib_accessors_list* next = al->next;
