@@ -27,6 +27,29 @@ GRIB_INLINE static int grib_inline_strcmp(const char* a, const char* b)
     return (*a == 0 && *b == 0) ? 0 : 1;
 }
 
+/* Debug utility function to track GRIB packing/repacking issues */
+static void print_debug_info__set_double_array(grib_handle* h, const char* func, const char* name, const double* val, size_t length)
+{
+    size_t N = 7, i = 0;
+    double minVal = DBL_MAX, maxVal = -DBL_MAX;
+    Assert( h->context->debug );
+
+    if (length <= N)
+        N = length;
+    fprintf(stderr, "ECCODES DEBUG %s key=%s %lu values (", func, name, (unsigned long)length);
+    for (i = 0; i < N; ++i) {
+        if (i != 0) fprintf(stderr,", ");
+        fprintf(stderr, "%g", val[i]);
+    }
+    if (N >= length) fprintf(stderr, ") ");
+    else fprintf(stderr, "...) ");
+    for (i = 0; i < length; ++i) {
+        if (val[i] < minVal) minVal = val[i];
+        if (val[i] > maxVal) maxVal = val[i];
+    }
+    fprintf(stderr, "min=%g, max=%g\n",minVal,maxVal);
+}
+
 int grib_set_expression(grib_handle* h, const char* name, grib_expression* e)
 {
     grib_accessor* a = grib_find_accessor(h, name);
@@ -467,7 +490,7 @@ int grib_set_bytes_internal(grib_handle* h, const char* name, const unsigned cha
             return grib_dependency_notify_change(a);
         }
 
-        grib_context_log(h->context, GRIB_LOG_ERROR, "unable to set %s=%ld as bytes (%s)",
+        grib_context_log(h->context, GRIB_LOG_ERROR, "unable to set %s=%s as bytes (%s)",
                          name, val, grib_get_error_message(ret));
         return ret;
     }
@@ -599,7 +622,9 @@ int grib_is_missing_string(grib_accessor* a, unsigned char* x, size_t len)
         }
     }
 
-    ret = (a == NULL || ((a->flags & GRIB_ACCESSOR_FLAG_CAN_BE_MISSING) && ret == 1)) ? 1 : 0;
+    if (!a) return ret;
+
+    ret = ( ((a->flags & GRIB_ACCESSOR_FLAG_CAN_BE_MISSING) && ret == 1) ) ? 1 : 0;
     return ret;
 }
 
@@ -706,8 +731,9 @@ int grib_set_double_array_internal(grib_handle* h, const char* name, const doubl
 {
     int ret = 0;
 
-    if (h->context->debug)
-        fprintf(stderr, "ECCODES DEBUG grib_set_double_array_internal key=%s %ld values\n", name, (long)length);
+    if (h->context->debug) {
+        print_debug_info__set_double_array(h, "grib_set_double_array_internal", name, val, length);
+    }
 
     if (length == 0) {
         grib_accessor* a = grib_find_accessor(h, name);
@@ -730,26 +756,7 @@ static int __grib_set_double_array(grib_handle* h, const char* name, const doubl
     size_t i = 0;
 
     if (h->context->debug) {
-        size_t N = 5;
-        /*double minVal = DBL_MAX, maxVal = -DBL_MAX;*/
-        if (length <= N)
-            N = length;
-        fprintf(stderr, "ECCODES DEBUG grib_set_double_array key=%s %ld values (", name, (long)length);
-        for (i = 0; i < N; ++i)
-            fprintf(stderr, " %g,", val[i]);
-        if (N >= length) fprintf(stderr, " )\n");
-        else fprintf(stderr, " ... )\n");
-        /*
-        * if (N >= length)
-        *    fprintf(stderr, " )\t");
-        * else
-        *     fprintf(stderr, " ... )\t");
-        * for (i = 0; i < length; ++i) {
-        *     if (val[i] < minVal) minVal = val[i];
-        *     if (val[i] > maxVal) maxVal = val[i];
-        * }
-        * fprintf(stderr, "min=%g, max=%g\n",minVal,maxVal);
-        */
+        print_debug_info__set_double_array(h, "__grib_set_double_array", name, val, length);
     }
 
     if (length == 0) {
@@ -1022,6 +1029,7 @@ int grib_points_get_values(grib_handle* h, grib_points* points, double* val)
 {
     int i, ret;
     grib_accessor* a = NULL;
+    fprintf(stderr, "Warning: The grib_points_get_values function is deprecated and will be removed later.");
 
     a = grib_find_accessor(h, "values");
 
@@ -1034,7 +1042,7 @@ int grib_points_get_values(grib_handle* h, grib_points* points, double* val)
     return GRIB_SUCCESS;
 }
 
-int grib_get_double_elements(const grib_handle* h, const char* name, int* index_array, long len, double* val_array)
+int grib_get_double_elements(const grib_handle* h, const char* name, const int* index_array, long len, double* val_array)
 {
     double* values = 0;
     int err        = 0;
